@@ -9,5 +9,7 @@
 #undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
 #undef HAVE_PROGRAM_INVOCATION_NAME
 #undef HAVE_DEVGTK
+#undef ENABLE_BONOBO
 #undef GS_PATH
+#undef LPR_PATH
 
