@@ -155,6 +155,7 @@ void about_callback(GtkWidget *widget, gpointer data)
 #else
                 "Jonathan Blandford <jrb@redhat.com>",
                 "Daniel M. German <dmg@csg.uwaterloo.ca>,",
+                "Dan E. Kelley <dan.kelley@dal.ca>",
                 "Werner Koerner <werner.koerner@zae.uni-wuerzburg.de>",
                 "Tuomas J. Lukka <lukka@iki.fi>",
                 "Jaka Mocnik <jaka@gnu.org>  (current maintainer)",
@@ -725,6 +726,26 @@ void key_pressed_event_callback(GtkWidget *widget, GdkEventKey *event,
 	;
 }
 
+void first_page_callback(GtkWidget *widget, gpointer data)
+{
+        ggv_window *ggv = (ggv_window *)data;
+        if(GTK_GS(ggv->gs)->loaded) {
+                if(GTK_GS(ggv->gs)->structured_doc)
+                        goto_page(ggv, 0);
+                else {
+                        gtk_gs_disable_interpreter(GTK_GS(ggv->gs));
+                        gtk_gs_enable_interpreter(GTK_GS(ggv->gs));
+                }
+        }
+}
+
+void last_page_callback(GtkWidget *widget, gpointer data)
+{
+        ggv_window *ggv = (ggv_window *) data;
+        if (GTK_GS(ggv->gs)->loaded)
+	        goto_page(ggv, GTK_GS(ggv->gs)->doc->numpages - 1);
+}
+
 void next_page_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *) data;
@@ -1153,7 +1174,7 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
         for(i = 0; i < MENU_ZOOM_SIZE - 1; i++){
                 if(active == p->zoom_choice[i]) {
                         gs_default_magnification = ZoomMenuMagnificationSteps[i];
-                        gtk_gs_set_default_zoom_factor(compute_zoom(gs_default_magnification));
+                        gtk_gs_set_default_zoom_factor(ggv_compute_zoom(gs_default_magnification));
                         break;
                 }
         }
