@@ -27,6 +27,8 @@ void show_toolbar_callback(GtkWidget *widget, gpointer data);
 void hide_panel_callback(GtkWidget *widget, gpointer data);
 void motion_callback(GtkWidget *widget, GdkEventMotion *event, gpointer data);
 void key_pressed_event_callback(GtkWidget *widget, GdkEventKey *event, gpointer data);
+void first_page_callback(GtkWidget *widget, gpointer data);
+void last_page_callback(GtkWidget *widget, gpointer data);
 void next_page_callback(GtkWidget *widget, gpointer data);
 void open_callback(GtkWidget *widget, gpointer data);
 void override_orientation_callback(GtkWidget *widget, gpointer data);
