@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 
-#include "config.h"
+#include <config.h>
 #include <ctype.h>
 #include <sys/stat.h>
 
@@ -14,6 +14,7 @@
 #include "stock/toggleeven.xpm"
 #include "stock/toggleodd.xpm"
 
+#include <math.h>
 
 /* Quote filename for system call */
 gchar *ggv_quote_filename (const gchar *str)
@@ -132,5 +133,9 @@ void ggv_stock_init (void)
 	gnome_stock_pixmap_register (STOCK_TOGGLE_EVEN, GNOME_STOCK_PIXMAP_REGULAR, &entries[3]);
 	gnome_stock_pixmap_register (STOCK_TOGGLE_ODD, GNOME_STOCK_PIXMAP_REGULAR, &entries[4]);
 	gnome_stock_pixmap_register (STOCK_CLEAR_ALL, GNOME_STOCK_PIXMAP_REGULAR, &entries[5]);
+}
 
+gfloat ggv_compute_zoom(gint zoom_spec)
+{
+	return (gfloat)pow(1.2, zoom_spec); /* The Knuth magstep formula rules */
 }
