@@ -4,6 +4,7 @@
 #define __GGV_MISC_H__
 
 #include <gnome.h>
+#include <math.h>
 
 /* Quote filename for system call */
 gchar *ggv_quote_filename (const gchar *str);
@@ -26,4 +27,6 @@ void ggv_set_tooltip(GtkWidget* w, const gchar* tip);
 
 void ggv_stock_init (void);
 
+gfloat ggv_compute_zoom(gint zoom_spec);
+
 #endif
