@@ -936,8 +936,11 @@ start_interpreter (GtkGS *gs)
 	int std_out[2]; /* pipe from interp stdout */
 	int std_err[2]; /* pipe from interp stderr */
 #define NUM_ARGS 100
-        char *argv[NUM_ARGS];
-        int argc = 0;
+#define NUM_GS_ARGS (NUM_ARGS - 10)
+
+        char *argv[NUM_ARGS], *dir, *gv_env;
+        char **gs_args;
+        int argc = 0, i;
 
 	if (!gs->gs_filename)
                 return 0;
@@ -948,7 +951,17 @@ start_interpreter (GtkGS *gs)
                 return 0;
         
         /* set up the args... */
-        argv[argc++] = gs_cmd;
+	/* change to directory where the input file is. This helps
+	 * with postscript-files which include other files using
+         * a relative path */
+	dir = g_dirname(gs->gs_filename);
+	chdir(dir);
+	g_free(dir);
+
+        /* set up the args... */
+        gs_args = g_strsplit(gs_cmd, " ", NUM_GS_ARGS);
+        for(i = 0; i < NUM_GS_ARGS && gs_args[i]; i++, argc++)
+                argv[argc] = gs_args[i];
         if( gs->antialiased ) 
 		argv[argc++] = "-sDEVICE=x11alpha";
         else 
@@ -971,8 +984,7 @@ start_interpreter (GtkGS *gs)
 
         if (!gs->reading_from_pipe && !gs->send_filename_to_gs) {
                 if (pipe (std_in) == -1) {
-                        /* FIXME: error handling needed */
-                        g_print("Unble to open pipe to ghostview\n");
+                        g_print("Unable to open pipe to ghostview\n");
                         return -1;
                 }
         }
@@ -1020,13 +1032,15 @@ start_interpreter (GtkGS *gs)
                         }
                 }
 
-		putenv (g_strdup_printf ("GHOSTVIEW=%ld",
-                                ((GdkWindowPrivate*)(gs->pstarget))->xwindow));
-
+                gv_env = g_strdup_printf ("GHOSTVIEW=%ld",
+                                          ((GdkWindowPrivate*)(gs->pstarget))->xwindow);
+                putenv (gv_env);
                 execvp(argv[0], argv);
                 
                 /* Notify error */
                 g_print("Unable to execute [%s]\n", argv[0]);
+                g_strfreev(gs_args);
+                g_free(gv_env);
 		_exit(1);
 		break;
 	default: /* parent */
@@ -1259,7 +1273,7 @@ static gchar *check_pdf (GtkGS *gs)
 		fname = ggv_quote_filename (filename);
 		filename_dsc = tempnam (g_get_tmp_dir(), "dsc");
 		filename_err = tempnam (g_get_tmp_dir(), "err");
-		cmd = g_strdup_printf (gs_scan_pdf_cmd, fname, filename_dsc);
+		cmd = g_strdup_printf (gs_scan_pdf_cmd, "\"", fname ,"\"", "\", filename_dsc");
 		g_free (fname);
 		/* this command (sometimes?) prints error messages to stdout! */
 		cmdline = g_strdup_printf ("%s >%s 2>&1", cmd, filename_err);
@@ -1322,7 +1336,16 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
  	gs->send_filename_to_gs = TRUE;
 	gs->current_page = -1;
         gs->loaded = FALSE;
-	gs->gs_filename = g_strdup (fname);
+        if(*fname == '/') {
+                /* an absolute path */
+                gs->gs_filename = g_strdup (fname);
+        }
+        else {
+                /* path relative to our cwd: make it absolute */
+                gchar *cwd = g_get_current_dir();
+                gs->gs_filename = g_strconcat(cwd, "/", fname, NULL);
+                g_free(cwd);
+        }
 
 	if ((gs->reading_from_pipe = (strcmp (fname, "-") == 0))) {
                 gs->send_filename_to_gs = FALSE;
@@ -1927,7 +1950,6 @@ gtk_gs_get_default_orientation()
         return gtkgs_defaults.fallback_orientation;
 }
 
-
 gfloat
 gtk_gs_get_default_zoom_factor()
 {
