@@ -70,8 +70,8 @@
 	/* list of standard paper sizes from Adobe's PPD. */
 
 struct documentmedia papersizes[PAPER_SIZE_COUNT+1] = {
+    {"BBox",	         0,  0},
     {"Letter",		 612,  792,},
-    {"LetterSmall",	 612,  792,},
     {"Tabloid",		 792, 1224,},
     {"Ledger",		1224,  792,},
     {"Legal",		 612, 1008,},
@@ -79,7 +79,6 @@ struct documentmedia papersizes[PAPER_SIZE_COUNT+1] = {
     {"Executive",	 540,  720,},
     {"A3",		 842, 1190,},
     {"A4",		 595,  842,},
-    {"A4Small",		 595,  842,},
     {"A5",		 420,  595,},
     {"B4",		 729, 1032,},
     {"B5",		 516,  729,},
@@ -101,6 +100,8 @@ static char *gettextline();
 static char *get_next_text();
 static int  blank();
 #endif
+static char    *skipped_line = "% ps_io_fgetchars: skipped line";
+
 
 /*
  *	psscan -- scan the PostScript file for document structuring comments.
@@ -217,7 +218,7 @@ static int  blank();
 #include <glib.h>
 
 
-struct document *psscan (FILE *file)
+struct document *psscan (FILE *file, int respect_eof)
 {
     struct document *doc;
     int bb_set = NONE;
@@ -498,7 +499,7 @@ struct document *psscan (FILE *file)
 		   DSCcomment(line) && iscomment(line+2, "+")) {
 		section_len += line_len;
 		next_char = line + length("%%+");
-		while ( (cp = get_next_text(next_char, &next_char)) ) {
+		while ((cp = get_next_text(next_char, &next_char)) ) {
 		    doc->media = g_renew (struct documentmedia,
 					  doc->media, doc->nummedia+1);
 		    doc->media[doc->nummedia].name = cp;
@@ -685,7 +686,7 @@ struct document *psscan (FILE *file)
     if (!(DSCcomment(line) &&
 	  (iscomment(line+2, "Page:") ||
 	   iscomment(line+2, "Trailer") ||
-	   iscomment(line+2, "EOF")))) {
+	   (respect_eof && iscomment(line+2, "EOF"))))) {
 	doc->beginsetup = beginsection;
 	beginsection = 0;
 	preread = 1;
@@ -695,7 +696,7 @@ struct document *psscan (FILE *file)
 	         (iscomment(line+2, "EndSetup") ||
 	          iscomment(line+2, "Page:") ||
 	          iscomment(line+2, "Trailer") ||
-	          iscomment(line+2, "EOF")))) {
+	          (respect_eof && iscomment(line+2, "EOF"))))) {
 	    if (!preread) section_len += line_len;
 	    preread = 0;
 	    if (!DSCcomment(line)) {
@@ -778,7 +779,7 @@ struct document *psscan (FILE *file)
 	      (iscomment(line+2, "EndSetup") ||
 	      (iscomment(line+2, "Page:") ||
 	       iscomment(line+2, "Trailer") ||
-	       (iscomment(line+2, "EOF"))))) &&
+	       (respect_eof && iscomment(line+2, "EOF"))))) &&
              (readline(line, sizeof line, file, &position, &line_len))) {
         section_len += line_len;
         doc->lensetup = section_len - line_len;
@@ -798,6 +799,7 @@ struct document *psscan (FILE *file)
 	section_len += line_len;
     }
 
+
 newpage:
     while (DSCcomment(line) && iscomment(line+2, "Page:")) {
 	if (maxpages == 0) {
@@ -834,7 +836,7 @@ continuepage:
 	       !(DSCcomment(line) &&
 	         (iscomment(line+2, "Page:") ||
 	          iscomment(line+2, "Trailer") ||
-	          iscomment(line+2, "EOF")))) {
+	          (respect_eof && iscomment(line+2, "EOF"))))) {
 	    section_len += line_len;
 	    if (!DSCcomment(line)) {
 		/* Do nothing */
@@ -928,7 +930,7 @@ continuepage:
     preread = 1;
     while ((preread ||
 	    readline(line, sizeof line, file, &position, &line_len)) &&
-	   !(DSCcomment(line) && iscomment(line+2, "EOF"))) {
+	   !(respect_eof && DSCcomment(line) && iscomment(line+2, "EOF"))) {
 	if (!preread) section_len += line_len;
 	preread = 0;
 	if (!DSCcomment(line)) {
@@ -951,6 +953,16 @@ continuepage:
 		}
 		goto newpage;
 	    }
+	} else if (!respect_eof && iscomment(line+2, "Trailer")) {
+	    /* What we thought was the start of the trailer was really */
+	    /* the trailer of an EPS on the page. */
+	    /* Set the end of the page to this trailer and keep scanning. */
+	    if (doc->numpages > 0) {
+		doc->pages[ doc->numpages-1 ].end = position;
+		doc->pages[ doc->numpages-1 ].len += section_len - line_len;
+	    }
+	    doc->begintrailer = position;
+	    section_len = line_len;
 	} else if (bb_set == ATEND && iscomment(line+2, "BoundingBox:")) {
 	    if (sscanf(line+length("%%BoundingBox:"), "%d %d %d %d",
 		       &(doc->boundingbox[LLX]),
@@ -1195,6 +1207,119 @@ get_next_text(line, next_char)
  *		    Also, skip over included documents (as indicated by
  *		    %%BeginDocument/%%EndDocument comments.)
  */
+/*
+static char * readline (fd, lineP, positionP, line_lenP)
+   FileData fd;
+   char **lineP;
+   long *positionP;
+   unsigned int *line_lenP;
+*/
+
+#ifdef WE_MIGHT_WANT_TO_INCLUDE_THIS_NEW_READLINE
+
+
+static char *
+readline(lineP, size, fp, positionP, line_lenP)
+    char *lineP;
+    int size;
+    FILE *fp;
+    long *positionP;
+    unsigned int *line_lenP;
+{
+   unsigned int nbytes=0;
+   int skipped=0;
+   char text[PSLINELENGTH];
+   char line[PSLINELENGTH];
+   char save[PSLINELENGTH];
+   char buf[BUFSIZ];
+   char *cp;
+   unsigned int num;
+   int i;
+
+   if (positionP) *positionP = ftell(fp);
+   cp = fgets(line, size, fp);
+   if (cp == NULL) {
+      *line_lenP = 0;
+      *lineP     = '\0';
+      return(NULL); 
+   }
+
+   *line_lenP = strlen(line);
+
+#define IS_COMMENT(comment)				\
+           (DSCcomment(line) && iscomment(line+2,(comment)))
+#define IS_BEGIN(comment)				\
+           (iscomment(line+7,(comment)))
+
+#define SKIP_WHILE(cond)				\
+	   while (readline(line, size, fp, NULL, &nbytes) \
+             && (cond)) *line_lenP += nbytes;\
+           skipped=1;
+
+#define SKIP_UNTIL_1(comment) {				\
+           SKIP_WHILE((!IS_COMMENT(comment)))           \
+        }
+#define SKIP_UNTIL_2(comment1,comment2) {		\
+           SKIP_WHILE((!IS_COMMENT(comment1) && !IS_COMMENT(comment2)))\
+        }
+
+   if  (!IS_COMMENT("Begin"))     {} /* Do nothing */
+   else if IS_BEGIN("Document:")  SKIP_UNTIL_1("EndDocument")
+   else if IS_BEGIN("Feature:")   SKIP_UNTIL_1("EndFeature")
+#ifdef USE_ACROREAD_WORKAROUND
+   else if IS_BEGIN("File")       SKIP_UNTIL_2("EndFile","EOF")
+#else
+   else if IS_BEGIN("File")       SKIP_UNTIL_1("EndFile")
+#endif
+   else if IS_BEGIN("Font")       SKIP_UNTIL_1("EndFont")
+   else if IS_BEGIN("ProcSet")    SKIP_UNTIL_1("EndProcSet")
+   else if IS_BEGIN("Resource")   SKIP_UNTIL_1("EndResource")
+   else if IS_BEGIN("Data:")      {
+	text[0] = '\0';
+	strcpy(save, line+7);
+	if (sscanf(line+length("%%BeginData:"), "%d %*s %s", &num, text) >= 1) {
+	    if (strcmp(text, "Lines") == 0) {
+		for (i=0; i < num; i++) {
+		    cp = fgets(line, size, fp);
+		    *line_lenP += cp ? strlen(line) : 0;
+		}
+	    } else {
+		while (num > BUFSIZ) {
+		    fread(buf, sizeof (char), BUFSIZ, fp);
+		    *line_lenP += BUFSIZ;
+		    num -= BUFSIZ;
+		}
+		fread(buf, sizeof (char), num, fp);
+		*line_lenP += num;
+	    }
+	}
+        SKIP_UNTIL_1("EndData")
+    } 
+   else if IS_BEGIN("Binary:") {
+        strcpy(save, line+7);
+	if(sscanf(line+length("%%BeginBinary:"), "%d", &num) == 1) {
+	    while (num > BUFSIZ) {
+		fread(buf, sizeof (char), BUFSIZ, fp);
+		*line_lenP += BUFSIZ;
+		num -= BUFSIZ;
+	    }
+	    fread(buf, sizeof (char), num, fp);
+	    *line_lenP += num;
+	}
+        SKIP_UNTIL_1("EndBinary")
+	*line_lenP += nbytes;
+    }
+
+   if (skipped) {
+      *line_lenP += nbytes;
+      strcpy(lineP, skipped_line);
+   } else {
+      strcpy(lineP, line);
+   }
+   return lineP;
+}
+
+#endif
 
 static char *
 readline(line, size, fp, position, line_len)
@@ -1312,6 +1437,7 @@ readline(line, size, fp, position, line_len)
     return cp;
 }
 
+
 /*
  *	pscopy -- copy lines of Postscript from a section of one file
  *		  to another file.
